@@ -1,5 +1,11 @@
 #
-# $Id: Split.pm,v 0.33 2004/01/01 18:23:23 st.schubiger Exp $
+# $Id: Split.pm,v 0.34 2004/01/01 23:02:18 st.schubiger Exp $
+
+=head1 NAME
+
+Dir::Split - Split the files of a directory to subdirectories.
+
+=cut
 
 package Dir::Split;
 
@@ -12,7 +18,7 @@ use File::Copy 'cp';
 use File::Path;
 use File::Spec;
 
-our $VERSION = 0.33;
+our $VERSION = '0.34';
 
 our (# external refs
         $Source_dir_ref, # scl
@@ -48,9 +54,24 @@ our (# external refs
         $Suffix,
     );
 
-=head1 NAME
+# opt presetting
+{
+    my ($PACKAGE, %Presets, %Var);
 
-Dir::Split - Split the files of a directory to subdirectories.
+    %Presets = (
+                 warn =>  {  dir  =>    "exists (d)\t",
+                             file =>    "exists (f)\t",
+                 },
+    );
+
+    $PACKAGE = __PACKAGE__;
+
+    $Var{'warn'} = $PACKAGE.'::Warn';
+    no strict 'refs';
+
+    $Var{'warn'}{'dir'} = $Presets{'warn'}{'dir'} unless $Var{'warn'}{'dir'};
+    $Var{'warn'}{'file'} = $Presets{'warn'}{'file'} unless $Var{'warn'}{'file'};
+}
 
 =head1 SYNOPSIS
 
@@ -106,158 +127,11 @@ Object constructor.
 
 C<%behavior> contains the options that will influence the splitting process.
 
-=over 4
-
-=item numeric splitting
-
-Split files to subdirectories with a numeric suffix. Numbering may
-be continued or started at 1 one each time. Options are explained below.
-See EXAMPLES to gain an understanding how numeric splitting works.
-
- %behavior = (  mode    =>    'num',
-
-                options => {  verbose        =>           1,
-                              warn           =>       'all',
-                              override       =>      'none',
-                },
-
-                sub_dir => {  identifier     =>    'system',
-                              file_limit     =>           2,
-                              file_sort      =>         '+',
-                },
-
-                suffix  => {  separator      =>         '-',
-                              continue_num   =>         'y',
-                              length         =>           5,
-                },
- );
-
-=item characteristic splitting
-
-Split files to subdirectories with a characteristic suffix. Files
-are assigned to subdirectories which suffixes correspond with the leading character
-of the filenames. Options are explained below. See EXAMPLES to gain an understanding
-how characteristic splitting works.
-
- %behavior = (  mode    =>    'char',
-
-                options => {  verbose     =>           1,
-                              warn        =>       'all',
-                              override    =>      'none',
-                },
-
-                sub_dir => {  identifier  =>    'system',
-                },
-
-                suffix  => {  separator   =>         '-',
-                              case        =>     'lower',
-                },
-
- );
-
-=item generic behavior
-
-=over 4
-
-=item C<mode>
-
-string - either I<num> for numeric or I<char> for characteristic.
-
-=item C<options/verbose>
-
-integer - verbosity; if enabled, mkpath will output the pathes
-on creating subdirectories.
-
- MODES
-   0  disabled
-   1  enabled
-
-=item C<options/warn>
-
-string - warn upon the encounter of existing files/dirs.
-
- LEVELS
-   none
-   files
-   dirs
-   all
-
-=item C<options/override>
-
-string - override of existing files/dirs.
-
- LEVELS
-   none
-   files
-   dirs
-   all
-
-=item C<sub_dir/identifier>
-
-string - prefix of each subdirectory created.
-
-=item C<suffix/separator>
-
-string - separates the identifier from the suffix.
-
-=back
-
-=item numeric behavior
-
-=over 4
-
-=item C<sub_dir/file_limit>
-
-integer - limit of files per subdirectory.
-
-=item C<sub_dir/file_sort>
-
-string - sort order of files.
-
- MODES
-   +  ascending
-   -  descending
-
-=item C<suffix/continue_num>
-
-string - numbering continuation (will start at 1 if no).
-
- MODES
-   y  yes
-   n  no
-
-=item C<suffix/length>
-
-integer - amount of zeros to be added to the suffix.
-
-=back
-
-Differing identifiers or separators do affect the numbering e.g. I<systm-> does
-not equal I<system->, I<system_> does not equal I<system->. C<file_limit>, C<file_sort>
-and C<length> options have no influence on decisions whether the numbering shall
-be continued, whereas C<identifier>, C<separator> and C<continue_num> do.
-
-=item characteristic behavior
-
-=over 4
-
-=item C<suffix/case>
-
-string - lower/upper case of the suffix.
-
- MODES
-   lower
-   upper
-
-=back
-
-=back
-
 =cut
 
 sub new {
     my ($pkg, $Opt_ref) = @_;
-    croak q~Syntax: Dir::Split->new (\%behavior)~
+    croak q~usage: Dir::Split->new (\%behavior)~
       unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
@@ -307,7 +181,7 @@ if none, it will return undef.
 sub split {
     my $self = shift;
     ($Source_dir_ref, $Target_dir_ref) = @_;
-    croak q~Syntax: $obj->split (\$source_dir, \$target_dir)~
+    croak q~usage: $obj->split (\$source_dir, \$target_dir)~
       unless ref $Source_dir_ref eq 'SCALAR' && ref $Target_dir_ref eq 'SCALAR';
 
     # opts refs
@@ -375,10 +249,10 @@ sub _sanity_input {
         unless ($$Verbose_ref =~ /^0|1$/) {
             $err_input = $err_msg{'verbosity'}; last;
         }
-        unless ($$Warn_ref =~ /^none|files|dirs|all$/) {
+        unless ($$Warn_ref =~ /^none|file|dir|all$/) {
             $err_input = $err_msg{'warn'}; last;
         }
-        unless ($$Override_ref =~ /^none|files|dirs|all$/) {
+        unless ($$Override_ref =~ /^none|file|dir|all$/) {
             $err_input = $err_msg{'override'}; last;
         }
         unless ($$Ident_ref =~ /\w/) {
@@ -479,7 +353,7 @@ sub _suffix_num {
             # extract exist. identifier
             ($_) = /(.+?)$sep(.*)/;
             # increase suffix to highest number
-            if ($$Ident_ref eq $_ && $2 !~ /\w/) {
+            if ($$Ident_ref eq $_ && $2 !~ /[a-z]/i) {
                $$Suffix_ref = $2 if $2 > $$Suffix_ref;
             }
         }
@@ -581,8 +455,8 @@ sub _mkpath {
     $$Path_ref = File::Spec->catfile($$Target_dir_ref, "$$Ident_ref$$Sep_ref$Suffix");
 
     if (-e $$Path_ref) {
-        warn "$$Path_ref exists.\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'dirs';
-        return unless $$Override_ref eq 'all' || $$Override_ref eq 'dirs';
+        warn "$Dir::Split::Warn{'dir'} $$Path_ref\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'dir';
+        return unless $$Override_ref eq 'all' || $$Override_ref eq 'dir';
     }
     mkpath $$Path_ref, $$Verbose_ref or croak qq~Could not create subdir $$Path_ref: $!~;
 }
@@ -601,8 +475,8 @@ sub _cp_unlink {
     $file = File::Spec->catfile($$Source_dir_ref, $file);
 
     if (-e $path_full) {
-        warn "$path_full exists.\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'files';
-        return unless $$Override_ref eq 'all' || $$Override_ref eq 'files';
+        warn "$Dir::Split::Warn{'file'} $path_full \n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'file';
+        return unless $$Override_ref eq 'all' || $$Override_ref eq 'file';
     }
     cp $file, $path_full or
       croak qq~Could not copy file $file to subdir $path_full: $!~;
@@ -612,9 +486,165 @@ sub _cp_unlink {
 }
 
 1;
-
 __END__
 
+=head1 OPTIONS
+
+=head2 numeric splitting
+
+Split files to subdirectories with a numeric suffix. Numbering may
+be continued or started at 1 one each time. Options are explained below.
+See EXAMPLES to gain an understanding how numeric splitting works.
+
+    %behavior = (  mode    =>    'num',
+
+                   options => {  verbose        =>           1,
+                                 warn           =>       'all',
+                                 override       =>      'none',
+                   },
+
+                   sub_dir => {  identifier     =>    'system',
+                                 file_limit     =>           2,
+                                 file_sort      =>         '+',
+                   },
+
+                   suffix  => {  separator      =>         '-',
+                                 continue_num   =>         'y',
+                                 length         =>           5,
+                   },
+    );
+
+=head2 characteristic splitting
+
+Split files to subdirectories with a characteristic suffix. Files
+are assigned to subdirectories which suffixes correspond with the leading character
+of the filenames. Options are explained below. See EXAMPLES to gain an understanding
+how characteristic splitting works.
+
+    %behavior = (  mode    =>    'char',
+
+                   options => {  verbose     =>           1,
+                                 warn        =>       'all',
+                                 override    =>      'none',
+                   },
+
+                   sub_dir => {  identifier  =>    'system',
+                   },
+
+                   suffix  => {  separator   =>         '-',
+                                 case        =>     'lower',
+                   },
+
+    );
+
+=over 4
+
+=item generic behavior
+
+=over 4
+
+=item C<mode>
+
+string - either I<num> for numeric or I<char> for characteristic.
+
+=item C<options/verbose>
+
+integer - verbosity; if enabled, mkpath will output the pathes
+on creating subdirectories.
+
+ MODES
+   0  disabled
+   1  enabled
+
+=item C<options/warn>
+
+string - warn upon the encounter of existing files/dirs.
+
+ LEVELS
+   none
+   file
+   dir
+   all
+
+=item C<options/override>
+
+string - override of existing files/dirs.
+
+ LEVELS
+   none
+   file
+   dir
+   all
+
+=item C<sub_dir/identifier>
+
+string - prefix of each subdirectory created.
+
+=item C<suffix/separator>
+
+string - separates the identifier from the suffix.
+
+=back
+
+=item numeric behavior
+
+=over 4
+
+=item C<sub_dir/file_limit>
+
+integer - limit of files per subdirectory.
+
+=item C<sub_dir/file_sort>
+
+string - sort order of files.
+
+ MODES
+   +  ascending
+   -  descending
+
+=item C<suffix/continue_num>
+
+string - numbering continuation (will start at 1 if no).
+
+ MODES
+   y  yes
+   n  no
+
+=item C<suffix/length>
+
+integer - amount of zeros to be added to the suffix.
+
+=back
+
+Differing identifiers or separators do affect the numbering e.g. I<systm-> does
+not equal I<system->, I<system_> does not equal I<system->. C<file_limit>, C<file_sort>
+and C<length> options have no influence on decisions whether the numbering shall
+be continued, whereas C<identifier>, C<separator> and C<continue_num> do.
+
+=item characteristic behavior
+
+=over 4
+
+=item C<suffix/case>
+
+string - lower/upper case of the suffix.
+
+ MODES
+   lower
+   upper
+
+=back
+
+=back
+
+=head2 presets
+
+The warning messages upon the encounter of existing files/dirs.
+
+    %Dir::Split::Warn = (  dir  =>    "exists (d)\t",
+                           file =>    "exists (f)\t",
+    );
+
 =head1 EXAMPLES
 
 Assuming the source directory I</tmp/src> contains 5 files:
